pub unsafe extern "C" fn apr_allocator_mutex_get(
allocator: *mut apr_allocator_t,
) -> *mut apr_thread_mutex_tExpand description
Get the mutex currently set for the allocator @param allocator The allocator
pub unsafe extern "C" fn apr_allocator_mutex_get(
allocator: *mut apr_allocator_t,
) -> *mut apr_thread_mutex_tGet the mutex currently set for the allocator @param allocator The allocator