pub unsafe extern "C" fn apr_allocator_mutex_set(
allocator: *mut apr_allocator_t,
mutex: *mut apr_thread_mutex_t,
)Expand description
Set a mutex for the allocator to use @param allocator The allocator to set the mutex for @param mutex The mutex