pub unsafe extern "C" fn apr_app_initialize(
argc: *mut c_int,
argv: *mut *const *const c_char,
env: *mut *const *const c_char,
) -> apr_status_tExpand description
Set up an application with normalized argc, argv (and optionally env) in order to deal with platform-specific oddities, such as Win32 services, code pages and signals. This must be the first function called for any APR program. @param argc Pointer to the argc that may be corrected @param argv Pointer to the argv that may be corrected @param env Pointer to the env that may be corrected, may be NULL @remark See apr_initialize() if this is a library consumer of apr. Otherwise, this call is identical to apr_initialize(), and must be closed with a call to apr_terminate() at the end of program execution.