apr_array_cat

Function apr_array_cat 

pub unsafe extern "C" fn apr_array_cat(
    dst: *mut apr_array_header_t,
    src: *const apr_array_header_t,
)
Concatenate two arrays together. @param dst The destination array, and the one to go first in the combined array @param src The source array to add to the destination array