apr_array_make

Function apr_array_make 

pub unsafe extern "C" fn apr_array_make(
    p: *mut apr_pool_t,
    nelts: c_int,
    elt_size: c_int,
) -> *mut apr_array_header_t
Create an array. @param p The pool to allocate the memory out of @param nelts the number of elements in the initial array @param elt_size The size of each element in the array. @return The new array