apr_array_pstrcat

Function apr_array_pstrcat 

pub unsafe extern "C" fn apr_array_pstrcat(
    p: *mut apr_pool_t,
    arr: *const apr_array_header_t,
    sep: c_char,
) -> *mut c_char
Generate a new string from the apr_pool_t containing the concatenated sequence of substrings referenced as elements within the array. The string will be empty if all substrings are empty or null, or if there are no elements in the array. If sep is non-NUL, it will be inserted between elements as a separator. @param p The pool to allocate the string out of @param arr The array to generate the string from @param sep The separator to use @return A string containing all of the data in the array.