apr_array_push

Function apr_array_push 

pub unsafe extern "C" fn apr_array_push(
    arr: *mut apr_array_header_t,
) -> *mut c_void
Add a new element to an array (as a first-in, last-out stack). @param arr The array to add an element to. @return Location for the new element in the array. @remark If there are no free spots in the array, then this function will allocate new space for the new element.