pub unsafe extern "C" fn apr_base64_encode_len(len: c_int) -> c_intExpand description
Given the length of an un-encoded string, get the length of the encoded string. @param len the length of an unencoded string. @return the length of the string after it is encoded, including the trailing \0