apr_bcrypt_encode

Function apr_bcrypt_encode 

pub unsafe extern "C" fn apr_bcrypt_encode(
    pw: *const c_char,
    count: c_uint,
    salt: *const c_uchar,
    salt_len: apr_size_t,
    out: *mut c_char,
    out_len: apr_size_t,
) -> apr_status_t
Encode a password using the bcrypt algorithm @param password The password to encode @param count The cost of the encoding, possible values are 4 to 31 @param salt Pointer to binary data to be used as salt for the encoding @param salt_len The size of the salt data (must be >= 16) @param out The string to store the encoded password in @param out_len The size of the result buffer (must be >= 61)