apr_date_parse_http

Function apr_date_parse_http 

pub unsafe extern "C" fn apr_date_parse_http(
    date: *const c_char,
) -> apr_time_t
Parses an HTTP date in one of three standard forms:

    Sun, 06 Nov 1994 08:49:37 GMT  ; RFC 822, updated by RFC 1123
    Sunday, 06-Nov-94 08:49:37 GMT ; RFC 850, obsoleted by RFC 1036
    Sun Nov  6 08:49:37 1994       ; ANSI C's asctime() format
@param date The date in one of the three formats above @return the apr_time_t number of microseconds since 1 Jan 1970 GMT, or 0 if this would be out of range or if the date is invalid.