apr_file_printf

Function apr_file_printf 

pub unsafe extern "C" fn apr_file_printf(
    fptr: *mut apr_file_t,
    format: *const c_char,
    ...
) -> c_int
Write a string to a file using a printf format. @param fptr The file to write to. @param format The format string @param … The values to substitute in the format string @return The number of bytes written