pub unsafe extern "C" fn apr_filepath_list_split(
pathelts: *mut *mut apr_array_header_t,
liststr: *const c_char,
p: *mut apr_pool_t,
) -> apr_status_tExpand description
Split a search path into separate components @param pathelts the returned components of the search path @param liststr the search path (e.g., getenv(“PATH”)) @param p the pool to allocate the array and path components from @remark empty path components do not become part of @a pathelts. @remark the path separator in @a liststr is system specific; e.g., ‘:’ on Unix, ‘;’ on Windows, etc.