pub unsafe extern "C" fn apr_generate_random_bytes(
buf: *mut c_uchar,
length: apr_size_t,
) -> apr_status_tExpand description
Generate random bytes. @param buf Buffer to fill with random bytes @param length Length of buffer in bytes
pub unsafe extern "C" fn apr_generate_random_bytes(
buf: *mut c_uchar,
length: apr_size_t,
) -> apr_status_tGenerate random bytes. @param buf Buffer to fill with random bytes @param length Length of buffer in bytes