apr_initialize

Function apr_initialize 

pub unsafe extern "C" fn apr_initialize() -> apr_status_t
Setup any APR internal data structures. This MUST be the first function called for any APR library. It is safe to call apr_initialize several times as long as apr_terminate() is called the same number of times. @remark See apr_app_initialize() if this is an application, rather than a library consumer of apr.