apr_palloc

Function apr_palloc 

pub unsafe extern "C" fn apr_palloc(
    p: *mut apr_pool_t,
    size: apr_size_t,
) -> *mut c_void
Allocate a block of memory from a pool @param p The pool to allocate from @param size The amount of memory to allocate @return The allocated memory