pub unsafe extern "C" fn apr_pool_allocator_get(
pool: *mut apr_pool_t,
) -> *mut apr_allocator_tExpand description
Find the pool’s allocator @param pool The pool to get the allocator from.
pub unsafe extern "C" fn apr_pool_allocator_get(
pool: *mut apr_pool_t,
) -> *mut apr_allocator_tFind the pool’s allocator @param pool The pool to get the allocator from.