apr_pool_clear_debug

Function apr_pool_clear_debug 

pub unsafe extern "C" fn apr_pool_clear_debug(
    p: *mut apr_pool_t,
    file_line: *const c_char,
)
Debug version of apr_pool_clear. @param p See: apr_pool_clear. @param file_line Where the function is called from. This is usually APR_POOL__FILE_LINE__. @remark Only available when APR_POOL_DEBUG is defined. Call this directly if you have your apr_pool_clear calls in a wrapper function and wish to override the file_line argument to reflect the caller of your wrapper function. If you do not have apr_pool_clear in a wrapper, trust the macro and don’t call apr_pool_destroy_clear directly.