pub unsafe extern "C" fn apr_pool_create_ex_debug(
newpool: *mut *mut apr_pool_t,
parent: *mut apr_pool_t,
abort_fn: apr_abortfunc_t,
allocator: *mut apr_allocator_t,
file_line: *const c_char,
) -> apr_status_tExpand description
Debug version of apr_pool_create_ex. @param newpool @see apr_pool_create. @param parent @see apr_pool_create. @param abort_fn @see apr_pool_create. @param allocator @see apr_pool_create. @param file_line Where the function is called from. This is usually APR_POOL__FILE_LINE__. @remark Only available when APR_POOL_DEBUG is defined. Call this directly if you have your apr_pool_create_ex calls in a wrapper function and wish to override the file_line argument to reflect the caller of your wrapper function. If you do not have apr_pool_create_ex in a wrapper, trust the macro and don’t call apr_pool_create_ex_debug directly.