apr_psprintf

Function apr_psprintf 

pub unsafe extern "C" fn apr_psprintf(
    p: *mut apr_pool_t,
    fmt: *const c_char,
    ...
) -> *mut c_char
printf-style style printing routine. The data is output to a string allocated from a pool @param p The pool to allocate out of @param fmt The format of the string @param … The arguments to use while printing the data @return The new string