apr_pvsprintf

Function apr_pvsprintf 

pub unsafe extern "C" fn apr_pvsprintf(
    p: *mut apr_pool_t,
    fmt: *const c_char,
    ap: *mut __va_list_tag,
) -> *mut c_char
printf-style style printing routine. The data is output to a string allocated from a pool @param p The pool to allocate out of @param fmt The format of the string @param ap The arguments to use while printing the data @return The new string