pub unsafe extern "C" fn apr_queue_term(
queue: *mut apr_queue_t,
) -> apr_status_tExpand description
terminate the queue, sending an interrupt to all the blocking threads
@param queue the queue
pub unsafe extern "C" fn apr_queue_term(
queue: *mut apr_queue_t,
) -> apr_status_tterminate the queue, sending an interrupt to all the blocking threads
@param queue the queue