pub unsafe extern "C" fn apr_socket_accept(
new_sock: *mut *mut apr_socket_t,
sock: *mut apr_socket_t,
connection_pool: *mut apr_pool_t,
) -> apr_status_tExpand description
Accept a new connection request @param new_sock A copy of the socket that is connected to the socket that made the connection request. This is the socket which should be used for all future communication. @param sock The socket we are listening on. @param connection_pool The pool for the new socket. @note The pool will be used by various functions that operate on the socket. The caller must ensure that it is not used by other threads at the same time.