apr_socket_connect

Function apr_socket_connect 

pub unsafe extern "C" fn apr_socket_connect(
    sock: *mut apr_socket_t,
    sa: *mut apr_sockaddr_t,
) -> apr_status_t
Issue a connection request to a socket either on the same machine or a different one. @param sock The socket we wish to use for our side of the connection @param sa The address of the machine we wish to connect to.