apr_socket_send

Function apr_socket_send 

pub unsafe extern "C" fn apr_socket_send(
    sock: *mut apr_socket_t,
    buf: *const c_char,
    len: *mut apr_size_t,
) -> apr_status_t
Send data over a network. @param sock The socket to send the data over. @param buf The buffer which contains the data to be sent. @param len On entry, the number of bytes to send; on exit, the number of bytes sent. @remark

This functions acts like a blocking write by default.  To change
this behavior, use apr_socket_timeout_set() or the APR_SO_NONBLOCK
socket option.

It is possible for both bytes to be sent and an error to be returned.

APR_EINTR is never returned.