apr_socket_sendv

Function apr_socket_sendv 

pub unsafe extern "C" fn apr_socket_sendv(
    sock: *mut apr_socket_t,
    vec: *const iovec,
    nvec: apr_int32_t,
    len: *mut apr_size_t,
) -> apr_status_t
Send multiple buffers over a network. @param sock The socket to send the data over. @param vec The array of iovec structs containing the data to send @param nvec The number of iovec structs in the array @param len Receives the number of bytes actually written @remark

This functions acts like a blocking write by default.  To change
this behavior, use apr_socket_timeout_set() or the APR_SO_NONBLOCK
socket option.
The number of bytes actually sent is stored in argument 4.

It is possible for both bytes to be sent and an error to be returned.

APR_EINTR is never returned.