apr_table_clone

Function apr_table_clone 

pub unsafe extern "C" fn apr_table_clone(
    p: *mut apr_pool_t,
    t: *const apr_table_t,
) -> *mut apr_table_t
Create a new table whose contents are deep copied from the given table. A deep copy operation copies all fields, and makes copies of dynamically allocated memory pointed to by the fields. @param p The pool to allocate the new table out of @param t The table to clone @return A deep copy of the table passed in