apr_thread_data_set

Function apr_thread_data_set 

pub unsafe extern "C" fn apr_thread_data_set(
    data: *mut c_void,
    key: *const c_char,
    cleanup: Option<unsafe extern "C" fn(arg1: *mut c_void) -> apr_status_t>,
    thread: *mut apr_thread_t,
) -> apr_status_t
Set user data associated with the current thread. @param data The user data to associate with the thread. @param key The key to use for associating the data with the thread @param cleanup The cleanup routine to use when the thread is destroyed. @param thread The currently open thread.