pub unsafe extern "C" fn apr_thread_pool_get(
thethread: *const apr_thread_t,
) -> *mut apr_pool_tExpand description
Get the child-pool used by the thread from the thread info. @return apr_pool_t the pool
pub unsafe extern "C" fn apr_thread_pool_get(
thethread: *const apr_thread_t,
) -> *mut apr_pool_tGet the child-pool used by the thread from the thread info. @return apr_pool_t the pool