apr_threadkey_data_get

Function apr_threadkey_data_get 

pub unsafe extern "C" fn apr_threadkey_data_get(
    data: *mut *mut c_void,
    key: *const c_char,
    threadkey: *mut apr_threadkey_t,
) -> apr_status_t
Return the pool associated with the current threadkey. @param data The user data associated with the threadkey. @param key The key associated with the data @param threadkey The currently open threadkey.