apr_threadkey_data_set

Function apr_threadkey_data_set 

pub unsafe extern "C" fn apr_threadkey_data_set(
    data: *mut c_void,
    key: *const c_char,
    cleanup: Option<unsafe extern "C" fn(arg1: *mut c_void) -> apr_status_t>,
    threadkey: *mut apr_threadkey_t,
) -> apr_status_t
Return the pool associated with the current threadkey. @param data The data to set. @param key The key to associate with the data. @param cleanup The cleanup routine to use when the file is destroyed. @param threadkey The currently open threadkey.