pub unsafe extern "C" fn apr_xml_parser_create(
pool: *mut apr_pool_t,
) -> *mut apr_xml_parserExpand description
Create an XML parser @param pool The pool for allocating the parser and the parse results. @return The new parser.
pub unsafe extern "C" fn apr_xml_parser_create(
pool: *mut apr_pool_t,
) -> *mut apr_xml_parserCreate an XML parser @param pool The pool for allocating the parser and the parse results. @return The new parser.