apr_xml_parser_done

Function apr_xml_parser_done 

pub unsafe extern "C" fn apr_xml_parser_done(
    parser: *mut apr_xml_parser,
    pdoc: *mut *mut apr_xml_doc,
) -> apr_status_t
Terminate the parsing and return the result @param parser The XML parser for parsing this data. @param pdoc The resulting parse information. May be NULL to simply terminate the parsing without fetching the info. @return Any errors found during the final stage of parsing. @remark Use apr_xml_parser_geterror() to get more error information.