apr_xml_quote_string

Function apr_xml_quote_string 

pub unsafe extern "C" fn apr_xml_quote_string(
    p: *mut apr_pool_t,
    s: *const c_char,
    quotes: c_int,
) -> *const c_char
quote an XML string Replace ‘<’, ‘>’, and ‘&’ with ‘&lt;’, ‘&gt;’, and ‘&amp;’. @param p The pool to allocate out of @param s The string to quote @param quotes If quotes is true, then replace ‘"’ with ‘&quot;’. @return The quoted string @note If the string does not contain special characters, it is not duplicated into the pool and the original string is returned.