apr_getopt_t

Struct apr_getopt_t 

#[repr(C)]
pub struct apr_getopt_t { pub cont: *mut apr_pool_t, pub errfn: apr_getopt_err_fn_t, pub errarg: *mut c_void, pub ind: c_int, pub opt: c_int, pub reset: c_int, pub argc: c_int, pub argv: *mut *const c_char, pub place: *const c_char, pub interleave: c_int, pub skip_start: c_int, pub skip_end: c_int, }
Structure to store command line argument information.

Fields

cont: *mut apr_pool_t

context for processing

errfn: apr_getopt_err_fn_t

function to print error message (NULL == no messages)

errarg: *mut c_void

user defined first arg to pass to error message

ind: c_int

index into parent argv vector

opt: c_int

character checked for validity

reset: c_int

reset getopt

argc: c_int

count of arguments

argv: *mut *const c_char

array of pointers to arguments

place: *const c_char

argument associated with option

interleave: c_int

set to nonzero to support interleaving options with regular args

skip_start: c_int

start of non-option arguments skipped for interleaving

skip_end: c_int

end of non-option arguments skipped for interleaving