#[repr(C)]pub struct apr_hdtr_t {
pub headers: *mut iovec,
pub numheaders: c_int,
pub trailers: *mut iovec,
pub numtrailers: c_int,
}Expand description
A structure to encapsulate headers and trailers for apr_socket_sendfile
Fields
headers: *mut iovecAn iovec to store the headers sent before the file.
numheaders: c_intnumber of headers in the iovec
trailers: *mut iovecAn iovec to store the trailers sent after the file.
numtrailers: c_intnumber of trailers in the iovec