apr_memnode_t

Struct apr_memnode_t 

#[repr(C)]
pub struct apr_memnode_t { pub next: *mut apr_memnode_t, pub ref_: *mut *mut apr_memnode_t, pub index: apr_uint32_t, pub free_index: apr_uint32_t, pub first_avail: *mut c_char, pub endp: *mut c_char, }
basic memory node structure @note The next, ref and first_avail fields are available for use by the caller of apr_allocator_alloc(), the remaining fields are read-only. The next field has to be used with caution and sensibly set when the memnode is passed back to apr_allocator_free(). See apr_allocator_free() for details. The ref and first_avail fields will be properly restored by apr_allocator_free().

Fields

next: *mut apr_memnode_t

< next memnode

ref_: *mut *mut apr_memnode_t

< reference to self

index: apr_uint32_t

< size

free_index: apr_uint32_t

< how much free

first_avail: *mut c_char

< pointer to first free memory

endp: *mut c_char

< pointer to end of free memory