#[repr(C)]pub struct apr_sockaddr_t {
pub pool: *mut apr_pool_t,
pub hostname: *mut c_char,
pub servname: *mut c_char,
pub port: apr_port_t,
pub family: apr_int32_t,
pub salen: apr_socklen_t,
pub ipaddr_len: c_int,
pub addr_str_len: c_int,
pub ipaddr_ptr: *mut c_void,
pub next: *mut apr_sockaddr_t,
pub sa: apr_sockaddr_t__bindgen_ty_1,
}Expand description
APRs socket address type, used to ensure protocol independence
Fields
pool: *mut apr_pool_tThe pool to use…
hostname: *mut c_charThe hostname
servname: *mut c_charEither a string of the port number or the service name for the port
port: apr_port_tThe numeric port
family: apr_int32_tThe family
salen: apr_socklen_tHow big is the sockaddr we’re using?
ipaddr_len: c_intHow big is the ip address structure we’re using?
addr_str_len: c_intHow big should the address buffer be? 16 for v4 or 46 for v6 used in inet_ntop…
ipaddr_ptr: *mut c_voidThis points to the IP address structure within the appropriate sockaddr structure.
next: *mut apr_sockaddr_tIf multiple addresses were found by apr_sockaddr_info_get(), this points to a representation of the next address.
sa: apr_sockaddr_t__bindgen_ty_1Trait Implementations
Sourceimpl Clone for apr_sockaddr_t
impl Clone for apr_sockaddr_t
Sourcefn clone(&self) -> apr_sockaddr_t
fn clone(&self) -> apr_sockaddr_t
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for apr_sockaddr_t