#[repr(C)]pub struct apu_err_t {
pub reason: *const c_char,
pub msg: *const c_char,
pub rc: c_int,
}Expand description
This structure allows the underlying API error codes to be returned along with plain text error messages that explain to us mere mortals what really happened.
Fields
reason: *const c_charmsg: *const c_charrc: c_intTrait Implementations