apr_filetype_e

Type Alias apr_filetype_e 

pub type apr_filetype_e = c_uint;
apr_filetype_e values for the filetype member of the apr_file_info_t structure @warning Not all of the filetypes below can be determined. For example, a given platform might not correctly report a socket descriptor as APR_SOCK if that type isn’t well-identified on that platform. In such cases where a filetype exists but cannot be described by the recognized flags below, the filetype will be APR_UNKFILE. If the filetype member is not determined, the type will be APR_NOFILE.