pub unsafe extern "C" fn apr_allocator_align(
allocator: *mut apr_allocator_t,
size: apr_size_t,
) -> apr_size_tExpand description
Get the true size that would be allocated for the given size (including the header and alignment). @param allocator The allocator from which to the memory would be allocated @param size The size to align @return The aligned size (or zero on apr_size_t overflow)