apr_allocator_alloc

Function apr_allocator_alloc 

pub unsafe extern "C" fn apr_allocator_alloc(
    allocator: *mut apr_allocator_t,
    size: apr_size_t,
) -> *mut apr_memnode_t
Allocate a block of mem from the allocator @param allocator The allocator to allocate from @param size The size of the mem to allocate (excluding the memnode structure)