pub unsafe extern "C" fn apr_array_append(
p: *mut apr_pool_t,
first: *const apr_array_header_t,
second: *const apr_array_header_t,
) -> *mut apr_array_header_tExpand description
Append one array to the end of another, creating a new array in the process. @param p The pool to allocate the new array out of @param first The array to put first in the new array. @param second The array to put second in the new array. @return A new array containing the data from the two arrays passed in.