pub unsafe extern "C" fn apr_array_clear(arr: *mut apr_array_header_t)Expand description
Remove all elements from an array. @param arr The array to remove all elements from. @remark As the underlying storage is allocated from a pool, no memory is freed by this operation, but is available for reuse.