apr_array_copy

Function apr_array_copy 

pub unsafe extern "C" fn apr_array_copy(
    p: *mut apr_pool_t,
    arr: *const apr_array_header_t,
) -> *mut apr_array_header_t
Copy the entire array. @param p The pool to allocate the copy of the array out of @param arr The array to copy @return An exact copy of the array passed in @remark The alternate apr_array_copy_hdr() copies only the header, and arranges for the elements to be copied if (and only if) the code subsequently does a push or arraycat.