pub unsafe extern "C" fn apr_array_pop(
arr: *mut apr_array_header_t,
) -> *mut c_voidExpand description
Remove an element from an array (as a first-in, last-out stack). @param arr The array to remove an element from. @return Location of the element in the array. @remark If there are no elements in the array, NULL is returned.