pub unsafe extern "C" fn apr_file_buffer_set(
thefile: *mut apr_file_t,
buffer: *mut c_char,
bufsize: apr_size_t,
) -> apr_status_tExpand description
Give the specified apr file handle a new buffer @param thefile The file handle that is to be modified @param buffer The buffer @param bufsize The size of the buffer @remark It is possible to add a buffer to previously unbuffered file handles, the #APR_FOPEN_BUFFERED flag will be added to the file handle’s flags. Likewise, with buffer=NULL and bufsize=0 arguments it is possible to make a previously buffered file handle unbuffered.