pub unsafe extern "C" fn apr_filepath_encoding(
style: *mut c_int,
p: *mut apr_pool_t,
) -> apr_status_tExpand description
Determine the encoding used internally by the FilePath functions @param style points to a variable which receives the encoding style flag @param p the pool to allocate any working storage @remark Use apr_os_locale_encoding() and/or apr_os_default_encoding() to get the name of the path encoding if it’s not UTF-8.