pub unsafe extern "C" fn apr_pool_note_subprocess(
a: *mut apr_pool_t,
proc_: *mut apr_proc_t,
how: apr_kill_conditions_e,
)Expand description
Register a process to be killed when a pool dies. @param a The pool to use to define the processes lifetime @param proc The process to register @param how How to kill the process, one of:
APR_KILL_NEVER -- process is never sent any signals
APR_KILL_ALWAYS -- process is sent SIGKILL on apr_pool_t cleanup
APR_KILL_AFTER_TIMEOUT -- SIGTERM, wait 3 seconds, SIGKILL
APR_JUST_WAIT -- wait forever for the process to complete
APR_KILL_ONLY_ONCE -- send SIGTERM and then wait