pub unsafe extern "C" fn apr_proc_create(
new_proc: *mut apr_proc_t,
progname: *const c_char,
args: *const *const c_char,
env: *const *const c_char,
attr: *mut apr_procattr_t,
pool: *mut apr_pool_t,
) -> apr_status_tExpand description
Create a new process and execute a new program within that process. @param new_proc The resulting process handle. @param progname The program to run @param args the arguments to pass to the new program. The first one should be the program name. @param env The new environment table for the new process. This should be a list of NULL-terminated strings. This argument is ignored for APR_PROGRAM_ENV, APR_PROGRAM_PATH, and APR_SHELLCMD_ENV types of commands. @param attr the procattr we should use to determine how to create the new process @param pool The pool to use. @note This function returns without waiting for the new process to terminate; use apr_proc_wait for that.