pub unsafe extern "C" fn apr_socket_addr_get(
sa: *mut *mut apr_sockaddr_t,
which: apr_interface_e,
sock: *mut apr_socket_t,
) -> apr_status_tExpand description
Return an address associated with a socket; either the address to which the socket is bound locally or the address of the peer to which the socket is connected. @param sa The returned apr_sockaddr_t. @param which Whether to retrieve the local or remote address @param sock The socket to use