pub unsafe extern "C" fn apr_socket_bind(
sock: *mut apr_socket_t,
sa: *mut apr_sockaddr_t,
) -> apr_status_tExpand description
Bind the socket to its associated port @param sock The socket to bind @param sa The socket address to bind to @remark This may be where we will find out if there is any other process using the selected port.