pub unsafe extern "C" fn apr_socket_create(
new_sock: *mut *mut apr_socket_t,
family: c_int,
type_: c_int,
protocol: c_int,
cont: *mut apr_pool_t,
) -> apr_status_tExpand description
Create a socket. @param new_sock The new socket that has been set up. @param family The address family of the socket (e.g., APR_INET). @param type The type of the socket (e.g., SOCK_STREAM). @param protocol The protocol of the socket (e.g., APR_PROTO_TCP). @param cont The pool for the apr_socket_t and associated storage. @note The pool will be used by various functions that operate on the socket. The caller must ensure that it is not used by other threads at the same time.