apr_socket_data_get

Function apr_socket_data_get 

pub unsafe extern "C" fn apr_socket_data_get(
    data: *mut *mut c_void,
    key: *const c_char,
    sock: *mut apr_socket_t,
) -> apr_status_t
Return the data associated with the current socket @param data The user data associated with the socket. @param key The key to associate with the user data. @param sock The currently open socket.