pub unsafe extern "C" fn apr_socket_data_set(
sock: *mut apr_socket_t,
data: *mut c_void,
key: *const c_char,
cleanup: Option<unsafe extern "C" fn(arg1: *mut c_void) -> apr_status_t>,
) -> apr_status_tExpand description
Set the data associated with the current socket. @param sock The currently open socket. @param data The user data to associate with the socket. @param key The key to associate with the data. @param cleanup The cleanup to call when the socket is destroyed.