pub unsafe extern "C" fn apr_strftime(
s: *mut c_char,
retsize: *mut apr_size_t,
max: apr_size_t,
format: *const c_char,
tm: *mut apr_time_exp_t,
) -> apr_status_tExpand description
Formats the exploded time according to the format specified @param s string to write to @param retsize The length of the returned string @param max The maximum length of the string @param format The format for the time string @param tm The time to convert