pub unsafe extern "C" fn apr_table_set(
t: *mut apr_table_t,
key: *const c_char,
val: *const c_char,
)Expand description
Add a key/value pair to a table. If another element already exists with the same key, this will overwrite the old data. @param t The table to add the data to. @param key The key to use (case does not matter) @param val The value to add @remark When adding data, this function makes a copy of both the key and the value.