pub unsafe extern "C" fn apr_thread_create(
new_thread: *mut *mut apr_thread_t,
attr: *mut apr_threadattr_t,
func: apr_thread_start_t,
data: *mut c_void,
cont: *mut apr_pool_t,
) -> apr_status_tExpand description
Create a new thread of execution @param new_thread The newly created thread handle. @param attr The threadattr to use to determine how to create the thread @param func The function to start the new thread in @param data Any data to be passed to the starting function @param cont The pool to use