pub unsafe extern "C" fn apr_thread_data_get(
data: *mut *mut c_void,
key: *const c_char,
thread: *mut apr_thread_t,
) -> apr_status_tExpand description
Return user data associated with the current thread. @param data The user data associated with the thread. @param key The key to associate with the data @param thread The currently open thread.