pub unsafe extern "C" fn apr_xml_empty_elem(
p: *mut apr_pool_t,
elem: *const apr_xml_elem,
) -> *const c_charExpand description
empty XML element @param p The pool to allocate out of @param elem The XML element to empty @return the string that was stored in the XML element