pub unsafe extern "C" fn apr_xml_quote_string(
p: *mut apr_pool_t,
s: *const c_char,
quotes: c_int,
) -> *const c_charExpand description
quote an XML string Replace ‘<’, ‘>’, and ‘&’ with ‘<’, ‘>’, and ‘&’. @param p The pool to allocate out of @param s The string to quote @param quotes If quotes is true, then replace ‘"’ with ‘"’. @return The quoted string @note If the string does not contain special characters, it is not duplicated into the pool and the original string is returned.