#[repr(C)]pub struct apr_getopt_t {
pub cont: *mut apr_pool_t,
pub errfn: apr_getopt_err_fn_t,
pub errarg: *mut c_void,
pub ind: c_int,
pub opt: c_int,
pub reset: c_int,
pub argc: c_int,
pub argv: *mut *const c_char,
pub place: *const c_char,
pub interleave: c_int,
pub skip_start: c_int,
pub skip_end: c_int,
}Expand description
Structure to store command line argument information.
Fields
cont: *mut apr_pool_tcontext for processing
errfn: apr_getopt_err_fn_tfunction to print error message (NULL == no messages)
errarg: *mut c_voiduser defined first arg to pass to error message
ind: c_intindex into parent argv vector
opt: c_intcharacter checked for validity
reset: c_intreset getopt
argc: c_intcount of arguments
argv: *mut *const c_chararray of pointers to arguments
place: *const c_charargument associated with option
interleave: c_intset to nonzero to support interleaving options with regular args
skip_start: c_intstart of non-option arguments skipped for interleaving
skip_end: c_intend of non-option arguments skipped for interleaving